LocalBuildConfig class
The validated contents of a Flutter Local Build YAML configuration file.
Constructors
-
LocalBuildConfig({required Directory root, required List<
String> flutterCommand, required Map<String, AppConfig> apps, required Map<String, ProfileConfig> profiles, required Map<String, Object?> publishers, Map<String, Object?> notifiers = const {}, Map<String, Object?> versioning = const {}}) -
Creates an already-parsed configuration.
const
Properties
-
apps
→ Map<
String, AppConfig> -
Applications keyed by their configuration names.
final
-
flutterCommand
→ List<
String> -
Executable and leading arguments used to invoke Flutter.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
notifiers
→ Map<
String, Object?> -
Build notification settings keyed by notifier name.
final
-
profiles
→ Map<
String, ProfileConfig> -
Shared build profiles keyed by profile name.
final
-
publishers
→ Map<
String, Object?> -
Artifact publisher settings keyed by publisher name.
final
- root → Directory
-
Directory containing the source YAML file.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
versioning
→ Map<
String, Object?> -
Build-name and build-number resolution settings.
final
Methods
-
enabledNotifier(
String name) → Map< String, Object?> ? -
Returns notifier
namewhen enabled, otherwisenull. -
enabledPublisher(
String name) → Map< String, Object?> ? -
Returns publisher
namewhen enabled, otherwisenull. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
profileFor(
AppConfig app, String name) → ProfileConfig -
Resolves shared profile
namewith any override declared byapp. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
load(
File file) → LocalBuildConfig -
Loads and validates configuration from a YAML
file.